/**
 * Copyright (c) 2006 - 2008 Smaxe Ltd (www.smaxe.com).
 * All rights reserved.
 */
package script;

import com.smaxe.app.uv.agent.RtmpClientScript;
import com.smaxe.uv.stream.MediaStreamInfo;

import java.util.Map;

/**
 * <code>DummyRtmpClientScript</code> - base {@link RtmpClientScript} implementation.
 * 
 * @author Andrei Sochirca
 */
public class DummyRtmpClientScript extends RtmpClientScript
{
    /**
     * Constructor.
     */
    public DummyRtmpClientScript()
    {
    }
    
    // handlers
    /**
     * Invoked before user connects to the server to get connection arguments.
     * 
     * @return connection arguments
     */
    @Override
    public Object[] onStart()
    {
        return null;
    }
    
    /**
     * Notifies about connection to the server.
     * 
     * @param code
     * @param info connection info
     */
    @Override
    public void onConnect(final String code, final Map<String, Object> info)
    {
        super.onConnect(code, info); // equivalent to logger().log(ILogger.DEBUG, "onConnect", null /*t*/, code, info);
    }
    
    /**
     * Invoked after <code>time</code> milliseconds elapsed since connection established.
     * 
     * @param time time since connection is established (in milliseconds)
     */
    @Override
    public void onTime(final long time)
    {
        super.onTime(time); // equivalent to logger().log(ILogger.DEBUG, "onTime", null /*t*/, time);
    }
    
    /**
     * Notifies about connection status.
     * 
     * @param code status code
     * @param info status info
     */
    @Override
    public void onStatus(final String code, final Map<String, Object> info)
    {
        super.onStatus(code, info); // equivalent to logger().log(ILogger.DEBUG, "onStatus", null /*t*/, code, info);
    }
    
    /**
     * Notifies about disconnection from the server.
     * 
     * @param code
     * @param info disconnection info
     */
    @Override
    public void onDisconnect(final String code, final Map<String, Object> info)
    {
        super.onDisconnect(code, info); // equivalent to logger().log(ILogger.DEBUG, "onDisconnect", null /*t*/, code, info);
    }
    
    /**
     * Notifies about received server#method(args) result.
     * 
     * @param cid call id
     * @param method called method name
     * @param args called method arguments
     * @param result result
     */
    @Override
    public void onCallResult(final Object cid, final String method, final Object[] args, final Object result)
    {
        super.onCallResult(cid, method, args, result); // equivalent to logger().log(ILogger.DEBUG, "onCallResult", null /*t*/, cid, method, Arrays.toString(args), result);
    }
    
    /**
     * Notifies about received server#method(args) exception.
     * 
     * @param cid call id
     * @param method called method name
     * @param args called method arguments
     * @param e thrown exception
     * @param details details
     */
    @Override
    public void onCallException(final Object cid, final String method, final Object[] args, final Exception e, final Object details)
    {
        super.onCallException(cid, method, args, e, details); // equivalent to logger().log(ILogger.DEBUG, "onCallException", e, cid, method, Arrays.toString(args), e, details);
    }
    
    /**
     * Notifies about <code>stream</code> playback start.
     * 
     * @param stream playing stream name
     */
    @Override
    public void onPlayStart(final String stream)
    {
        super.onPlayStart(stream); // equivalent to logger().log(ILogger.DEBUG, "onPlayStart", null /*t*/, stream);
    }
    
    /**
     * Notifies about playing <code>stream</code> action.
     * 
     * @param stream playing stream name
     * @param action playing stream action
     * @param args playing stream arguments
     */
    @Override
    public void onPlayAction(final String stream, final String action, final Object... args)
    {
        super.onPlayAction(stream, action, args); // equivalent to logger().log(ILogger.DEBUG, "onPlayAction", null /*t*/, stream, action, Arrays.toString(args));
    }
    
    /**
     * Notifies about playing <code>stream</code> status.
     * 
     * @param stream playing stream name
     * @param code status code
     * @param info status info
     */
    @Override
    public void onPlayStatus(final String stream, final String code, final Map<String, Object> info)
    {
        super.onPlayStatus(stream, code, info); // equivalent to logger().log(ILogger.DEBUG, "onPlayStatus", null /*t*/, stream, code, info);
    }
    
    /**
     * Notifies about <code>stream</code> playback stop.
     * 
     * @param stream played stream name
     * @param info played stream info
     */
    @Override
    public void onPlayStop(final String stream, final MediaStreamInfo info)
    {
        super.onPlayStop(stream, info); // equivalent to logger().log(ILogger.DEBUG, "onPlayStop", null /*t*/, stream, info);
    }
    
    /**
     * Notifies about <code>stream</code> publish start.
     * 
     * @param stream published stream name
     */
    @Override
    public void onPublishStart(final String stream)
    {
        super.onPublishStart(stream); // equivalent to logger().log(ILogger.DEBUG, "onPublishStart", null /*t*/, stream);
    }
    
    /**
     * Notifies about published <code>stream</code> status.
     * 
     * @param stream published stream name
     * @param code status code
     * @param info status info
     */
    @Override
    public void onPublishStatus(final String stream, final String code, final Map<String, Object> info)
    {
        super.onPublishStatus(stream, code, info); // equivalent to logger().log(ILogger.DEBUG, "onPublishStatus", null /*t*/, stream, code, info);
    }
    
    /**
     * Notifies about <code>stream</code> publish stop.
     * 
     * @param stream published stream name
     */
    @Override
    public void onPublishStop(final String stream)
    {
        super.onPublishStop(stream); // equivalent to logger().log(ILogger.DEBUG, "onPublishStop", null /*t*/, stream);
    }
    
    /**
     * Notifies about connection to the shared object.
     * 
     * @param name shared object name
     */
    @Override
    public void onSharedObjectConnect(final String name)
    {
        super.onSharedObjectConnect(name); // equivalent to logger().log(ILogger.DEBUG, "onSharedObjectConnect", null /*t*/, name);
    }
    
    /**
     * Notifies about shared object action.
     * 
     * @param name shared object name
     * @param action action
     * @param args action arguments
     */
    @Override
    public void onSharedObjectAction(final String name,
            final String action, final Object... args)
    {
        super.onSharedObjectAction(name, action, args); // equivalent to logger().log(ILogger.DEBUG, "onSharedObjectAction", null /*t*/, name, action, Arrays.toString(args));
    }
    
    /**
     * Notifies about shared object attribute change.
     * 
     * @param name shared object name
     * @param attribute changed attribute
     * @param oldValue old value
     * @param newValue new value
     */
    @Override
    public void onSharedObjectChange(final String name,
            final String attribute, final Object oldValue, final Object newValue)
    {
        super.onSharedObjectChange(name, attribute, oldValue, newValue); // equivalent to logger().log(ILogger.DEBUG, "onSharedObjectChange", null /*t*/, name, attribute, oldValue, newValue);
    }
    
    /**
     * Notifies about shared object status.
     * 
     * @param name shared object name
     * @param status shared object status
     * @param description status description
     */
    @Override
    public void onSharedObjectStatus(final String name,
            final String status, final Object description)
    {
        super.onSharedObjectStatus(name, status, description); // equivalent to logger().log(ILogger.DEBUG, "onSharedObjectStatus", null /*t*/, name, status, description);
    }
    
    /**
     * Notifies about disconnection from the shared object.
     * 
     * @param name shared object name
     */
    @Override
    public void onSharedObjectDisconnect(final String name)
    {
        super.onSharedObjectDisconnect(name); // equivalent to logger().log(ILogger.DEBUG, "onSharedObjectDisconnect", null /*t*/, name);
    }
}